# pyjr

An assistance package for ETL, model development and validation.

[![PyPI](https://img.shields.io/pypi/v/pyjr?color=brightgreen&logoColor=lightgrey)](https://pypi.org/project/pyjr/)

## Description
*Project is not complete.*

## Getting Started
*Project is not complete.*

### Installing
The package can be accessed via pip install.

    pip install pyjr

### Future Work
* ~~Plot classes have not been vetted.~~
* Add arg parse to plot classes.
* ~~Documentation of classes and functions.~~
* Update to TimeSeries, Tuning and Features.
* Test all model classes and functions.
* Add to self-contained functions.

### Changelog
* 0.0.1 - *Initial Release*
  * This serves as a quick release to utilize the basic functionality.
* 0.0.2 - *Working Release*
  * This release has passed a cursory review. 
* 0.0.3 - *Plot Release*
  * This release adds improved plotting capabilities.
* 0.0.4 - *Plot Release+*
  * This release adds documentation to the plot classes.
* 0.0.5 - *Functional Release*
  * This release allows subpackages.
* 0.0.6 - *Class Updates*
  * This release adds Stat class, for rapid stat gathering.
* 0.0.7 - *Package Restructure*
  * This release intro's a new file structure.
* 0.0.8 - *Hot Fix*
  * Hotfix Release
* 0.0.9 - *Another Hot Fix*
  * Forgot to add folder to setup.py.